import styled from 'styled-components';

import defaultTheme from '../../theme';
import {
  paddable,
  flexbox,
  alignColumn,
  alignRow,
  textAlign,
} from '../../utils';

export interface BoxProps {
  centered?: boolean;
  padded?: boolean;
  size?: number | number[];
  type?: 'row' | 'column';
  verticalAlign?: 'start' | 'center' | 'end';
  floated?: 'left' | 'right';
  textAlign?: 'left' | 'right' | 'center' | 'justify';
}

export const Box = styled.div<BoxProps>(
  {
    display: 'flex',
    padding: '0.5em 0',
    position: 'relative',

    '&:first-of-type': {
      paddingTop: 0,
      paddingBottom: 0,
    },

    // Last but not second
    '&:last-of-type:not(:nth-child(2))': {
      paddingTop: 0,
    },
  },
  (props) => ({
    flexFlow: `${props.type} wrap`,
    ...(props.type === 'column' ? alignColumn(props) : alignRow(props)),
  }),
  textAlign,
  flexbox,
  paddable,
);

Box.defaultProps = {
  theme: defaultTheme,
  type: 'column',
};
